/*
 * Copyright 2018 Confluent Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.confluent.common.logging;

import org.apache.kafka.connect.data.SchemaAndValue;

import java.util.function.Supplier;

public interface StructuredLogger {
  String getName();

  void error(final Supplier<SchemaAndValue> msgSupplier);

  void error(final SchemaAndValue msg);

  void info(final Supplier<SchemaAndValue> msgSupplier);

  void info(final SchemaAndValue msg);

  void debug(final Supplier<SchemaAndValue> msgSupplier);

  void debug(final SchemaAndValue msg);
}
